# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import pytest

import cohesivenet
from cohesivenet.api.vns3.firewall_api import FirewallApi  # noqa: E501
from cohesivenet.rest import ApiException


@pytest.mark.licensed
class TestFirewallApi(object):
    """FirewallApi unit test stubs"""

    def test_delete_firewall_fw_set(self):
        """Test case for delete_firewall_fw_set

        """
        pass

    def test_delete_firewall_rule_by_position(self):
        """Test case for delete_firewall_rule_by_position

        """
        pass

    def test_delete_firewall_rule_by_rule(self):
        """Test case for delete_firewall_rule_by_rule

        """
        pass

    def test_delete_firewall_subgroup(self):
        """Test case for delete_firewall_subgroup

        """
        pass

    def test_get_firewall_fw_sets(self):
        """Test case for get_firewall_fw_sets

        """
        pass

    def test_get_firewall_rule_subgroups(self):
        """Test case for get_firewall_rule_subgroups

        """
        pass

    def test_get_firewall_rules(self):
        """Test case for get_firewall_rules

        """
        pass

    def test_post_create_firewall_rule(self):
        """Test case for post_create_firewall_rule

        """
        pass

    def test_post_create_firewall_subgroup_rule(self):
        """Test case for post_create_firewall_subgroup_rule

        """
        pass

    def test_put_reinitialize_fw_sets(self):
        """Test case for put_reinitialize_fw_sets

        """
        pass

    def test_put_reinitialize_subgroups(self):
        """Test case for put_reinitialize_subgroups

        """
        pass
